FileSection

Struct FileSection 

pub struct FileSection {
    pub name: String,
    pub content: Vec<Box<dyn FileSectionContent>>,
    /* private fields */
}

Fields

name: String

File section name.

content: Vec<Box<dyn FileSectionContent>>

File section content.

Implementations

Source

impl FileSection

pub fn new(name: impl Into<String>) -> Self

Creates a new FileSection.

pub fn from_template(template: &SectionTemplate) -> Result<Self>

Creates a new FileSection from a template.

pub fn indented_branch(&mut self, name: impl Into<String>) -> &mut Self

Gets or creates, if it doesn’t exist, an indented branch.

pub fn indexed_write<S: Into<String>>(&mut self, index: usize, content: S)

Writes the content to the file section at the specified index.

pub fn indexed_writeln<S: Into<String>>(&mut self, index: usize, content: S)

Writes the content to the file section at the specified index and adds a new line.

pub fn write<S: Into<String>>(&mut self, content: S)

Writes the content to the file buffer.

pub fn writeln<S: Into<String>>(&mut self, content: S)

Writes the content to the file buffer and adds a new line.

pub fn indent(&mut self) -> &mut Self

Increase the indentation level by 1.

pub fn dedent(&mut self) -> &mut Self

Decrease the indentation level by 1.

pub fn indentation(&mut self, indentation_level: usize) -> &mut Self

Sets the indentation level.