File

Struct File 

pub struct File {
    pub path: PathBuf,
    pub section: FileSection,
}
Structure representing a file path and its content.

Fields

path: PathBuf

File path.

section: FileSection

File Section.

Implementations

Source

impl File

pub fn from_template( path: impl AsRef<Path>, template: &SectionTemplate, ) -> Result<Self>

Creates a new file from a template.

pub fn new(path: impl AsRef<Path>) -> Self

Creates a new file with the specified path and content.

pub fn save(&self) -> Result<()>

Saves the file.

Methods from Deref<Target = FileSection>

pub fn indented_branch(&mut self, name: impl Into<String>) -> &mut Self

Gets or creates, if it doesn’t exist, an indented branch.

pub fn indexed_write<S: Into<String>>(&mut self, index: usize, content: S)

Writes the content to the file section at the specified index.

pub fn indexed_writeln<S: Into<String>>(&mut self, index: usize, content: S)

Writes the content to the file section at the specified index and adds a new line.

pub fn write<S: Into<String>>(&mut self, content: S)

Writes the content to the file buffer.

pub fn writeln<S: Into<String>>(&mut self, content: S)

Writes the content to the file buffer and adds a new line.

pub fn indent(&mut self) -> &mut Self

Increase the indentation level by 1.

pub fn dedent(&mut self) -> &mut Self

Decrease the indentation level by 1.

pub fn indentation(&mut self, indentation_level: usize) -> &mut Self

Sets the indentation level.