pub struct File {
pub path: PathBuf,
pub section: FileSection,
}Expand description
Structure representing a file path and its content.
Fields
path: PathBufFile path.
section: FileSectionFile Section.
Implementations
Methods from Deref<Target = FileSection>
Sourcepub fn indented_branch(&mut self, name: impl Into<String>) -> &mut Self
pub fn indented_branch(&mut self, name: impl Into<String>) -> &mut Self
Gets or creates, if it doesn’t exist, an indented branch.
Sourcepub fn indexed_write<S: Into<String>>(&mut self, index: usize, content: S)
pub fn indexed_write<S: Into<String>>(&mut self, index: usize, content: S)
Writes the content to the file section at the specified index.
Sourcepub fn indexed_writeln<S: Into<String>>(&mut self, index: usize, content: S)
pub fn indexed_writeln<S: Into<String>>(&mut self, index: usize, content: S)
Writes the content to the file section at the specified index and adds a new line.
Sourcepub fn writeln<S: Into<String>>(&mut self, content: S)
pub fn writeln<S: Into<String>>(&mut self, content: S)
Writes the content to the file buffer and adds a new line.
Sourcepub fn indentation(&mut self, indentation_level: usize) -> &mut Self
pub fn indentation(&mut self, indentation_level: usize) -> &mut Self
Sets the indentation level.